==> apache-iceberg-0.13.1.tar.gz: apache-iceberg-0.13.1/core/src/main/java/org/apache/iceberg/io/DataWriteResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iceberg.io;

import java.util.Collections;
import java.util.List;
import org.apache.iceberg.DataFile;

/**
 * A result of writing data files.
 * <p>
 * Note that objects of this class are NOT meant to be serialized. Task or delta writers will wrap
 * these results into their own serializable results that can be sent back to query engines.
 */
public class DataWriteResult {
  private final List<DataFile> dataFiles;

  public DataWriteResult(DataFile dataFile) {
    this.dataFiles = Collections.singletonList(dataFile);
  }

  public DataWriteResult(List<DataFile> dataFiles) {
    this.dataFiles = dataFiles;
  }

  public List<DataFile> dataFiles() {
    return dataFiles;
  }
}

==> apache-iceberg-1.10.0.tar.gz: apache-iceberg-1.10.0/core/src/main/java/org/apache/iceberg/io/DataWriteResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.io;

import java.util.Collections;
import java.util.List;
import org.apache.iceberg.DataFile;

/**
 * A result of writing data files.
 *
 * <p>Note that objects of this class are NOT meant to be serialized. Task or delta writers will
 * wrap these results into their own serializable results that can be sent back to query engines.
 */
public class DataWriteResult {
  private final List<DataFile> dataFiles;

  public DataWriteResult(DataFile dataFile) {
    this.dataFiles = Collections.singletonList(dataFile);
  }

  public DataWriteResult(List<DataFile> dataFiles) {
    this.dataFiles = dataFiles;
  }

  public List<DataFile> dataFiles() {
    return dataFiles;
  }
}
